@@ -713,7 +713,7 @@ bool SetSuperLUmpi()
 
 
 
-Init init;
+LOADINIT(Init);
 Init::Init()
 { 
   
