@@ -1741,7 +1741,7 @@ bool SetHypreSolver()
 
 
 }
-Init init;
+LOADINIT(Init);
 Init::Init()
 { 
   
