@@ -788,7 +788,7 @@ bool SetSuperLUmpi()
 
 
 
-Init init;
+LOADINIT(Init);
 Init::Init()
 { 
   
