@@ -698,7 +698,7 @@ bool Setpastixmpi()
 
 
 
-Init init;
+LOADINIT(Init);
 Init::Init()
 { 
   
