@@ -486,12 +486,12 @@ public:
   int BorderElementAdj(int i, int j) const 
       {
 	// be: border index, i and j index of vertex of be, i index of common vertex
-	int p2;
+	int p2=-1;
 	for (int p=BoundaryAdjacencesHead[i];p>=0;p=BoundaryAdjacencesLink[p])
 	  { 
 	    if ( !bedges[p2=p/2].in(vertices+j) )   return p2;
 	  }
-      } // Add J. Morice
+      return -1;} // Add J. Morice
   int nTonEdge(int it,int e) const { int k=3*it+e;return k==TheAdjacencesLink[k] ? 1 : 2;}
       
   void VerticesNumberOfEdge(const Triangle & T,int j,int & j0,int & j1) const 
