@@ -18,6 +18,6 @@ string StrVersionNumber(){
 //  buffer.precision(8);
 //  buffer<<VersionNumber();
   static char buffer[100];
-  sprintf(buffer," %9f (date Lun 29 aoû 2011 15:04:24 CEST)",VersionNumber());
-  return buffer; //.str()+" (date Lun 29 aoû 2011 15:04:24 CEST)" ;
+  sprintf(buffer," %9f (date Jeu 17 nov 2011 15:12:39 CET)",VersionNumber());
+  return buffer; //.str()+" (date Jeu 17 nov 2011 15:12:39 CET)" ;
 }
